#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Icinga2Confgen.CheckExistingUsers import CheckExistingUsers
from icinga2confgen.Checks.Icinga2Confgen.CheckGroupMembers import CheckGroupMembers
from icinga2confgen.Checks.Icinga2Confgen.CheckSSHDSecurity import CheckSSHDSecurity
from icinga2confgen.Checks.Icinga2Confgen.CheckUFWStatus import CheckUFWStatus
from icinga2confgen.Checks.MonitoringPlugins.CheckApt import CheckApt
from icinga2confgen.Checks.MonitoringPlugins.CheckDisk import CheckDisk
from icinga2confgen.Checks.MonitoringPlugins.CheckLoad import CheckLoad
from icinga2confgen.Checks.MonitoringPlugins.CheckNTPTime import CheckNTPTime
from icinga2confgen.Checks.MonitoringPlugins.CheckProcs import CheckProcs
from icinga2confgen.Checks.MonitoringPlugins.CheckSWAP import CheckSWAP
from icinga2confgen.Checks.MonitoringPlugins.CheckUsers import CheckUsers
from icinga2confgen.Checks.NagiosPlugins.CheckYum import CheckYum
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class DefaultLocalChecks:

    def __init__(self, servers=[], notifications=[], sudoers=[], additional_users=[]):
        self.__additional_users = additional_users
        self.__servers = servers
        self.__notifications = notifications
        self.__check_type = 'local'
        self.__check_load = True
        self.__check_apt = True
        self.__check_yum = False
        self.__check_users = True
        self.__check_swap = True
        self.__check_ntp_time = True
        self.__check_disk = True
        self.__check_sshd_security = True
        self.__check_sshd_running = True
        self.__check_mysqld_running = False
        self.__check_postgres_running = False
        self.__check_cron_running = True
        self.__check_crond_running = False
        self.__check_rsyslogd_running = True
        self.__check_nginx_running = False
        self.__check_apache_running = False
        self.__check_httpd_running = False
        self.__check_tomcat_running = False
        self.__check_php_fpm_running = False
        self.__check_freshclam_running = False
        self.__check_clamd_running = False
        self.__check_postfix_running = False
        self.__check_sudoers = True
        self.__check_normal_users = True
        self.__check_wheel = False
        self.__check_ufw = True
        self.__sudoers = sudoers
        self.__check_partitions = []
        self.__ufw_rules = []
        self.__ufw_defaults = ('deny', 'allow', 'deny')

    def check_load(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_load = enabled

        return self

    def is_checking_load(self):
        return self.__check_load

    def check_apt(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_apt = enabled

        return self

    def is_checking_apt(self):
        return self.__check_apt

    def check_yum(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_yum = enabled

        return self

    def is_checking_yum(self):
        return self.__check_yum

    def check_users(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_users = enabled

        return self

    def is_checking_users(self):
        return self.__check_users

    def check_swap(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_swap = enabled

        return self

    def is_checking_swap(self):
        return self.__check_swap

    def check_ntp_time(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_ntp_time = enabled

        return self

    def is_checking_ntp_time(self):
        return self.__check_ntp_time

    def check_disk(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_disk = enabled

        return self

    def is_checking_disk(self):
        return self.__check_disk

    def check_sshd_security(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_sshd_security = enabled

        return self

    def is_checking_sshd_security(self):
        return self.__check_sshd_security

    def check_sshd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_sshd_running = enabled

        return self

    def is_checking_sshd_running(self):
        return self.__check_sshd_running

    def check_freshclam_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_freshclam_running = enabled

        return self

    def is_checking_freshclam_running(self):
        return self.__check_freshclam_running

    def check_clamd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_clamd_running = enabled

        return self

    def is_checking_clamd_running(self):
        return self.__check_clamd_running

    def check_postfix_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_postfix_running = enabled

        return self

    def is_checking_postfix_running(self):
        return self.__check_postfix_running

    def check_mysqld_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_mysqld_running = enabled

        return self

    def is_checking_mysqld_running(self):
        return self.__check_mysqld_running

    def check_postgres_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_postgres_running = enabled

        return self

    def is_checking_postgres_running(self):
        return self.__check_postgres_running

    def check_cron_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_cron_running = enabled

        return self

    def is_checking_cron_running(self):
        return self.__check_cron_running

    def check_crond_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_crond_running = enabled

        return self

    def is_checking_crond_running(self):
        return self.__check_crond_running

    def check_rsyslogd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_rsyslogd_running = enabled

        return self

    def is_checking_rsyslogd_running(self):
        return self.__check_rsyslogd_running

    def check_nginx_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_nginx_running = enabled

        return self

    def is_checking_nginx_running(self):
        return self.__check_nginx_running

    def check_apache_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_apache_running = enabled

        return self

    def is_checking_apache_running(self):
        return self.__check_apache_running

    def check_httpd_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_httpd_running = enabled

        return self

    def is_checking_httpd_running(self):
        return self.__check_httpd_running

    def check_tomcat_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_tomcat_running = enabled

        return self

    def is_checking_tomcat_running(self):
        return self.__check_tomcat_running

    def check_php_fpm_running(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_php_fpm_running = enabled

        return self

    def is_checking_php_fpm_running(self):
        return self.__check_php_fpm_running

    def check_ufw(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_ufw = enabled

        return self

    def is_checking_ufw(self):
        return self.__check_ufw

    def add_ufw_rule(self, policy_from, policy_to, policy_action):
        ValueChecker.is_string(policy_from)
        ValueChecker.is_string(policy_to)
        ValueChecker.is_string(policy_action)
        self.__ufw_rules.append(
            (policy_from.replace(' ', '-'), policy_to.replace(' ', '-'), policy_action.replace(' ', '-')))
        return self

    def set_ufw_defaults(self, incoming, outgoing, routing):
        self.__ufw_defaults = tuple((incoming, outgoing, routing))
        return self

    def add_server(self, server):
        self.__servers.append(server)
        return self

    def get_server(self):
        return self.__servers

    def add_partition(self, id, path, warning_percent, critical_percent):
        ValueChecker.is_string(id)
        ValueChecker.is_string(path)
        ValueChecker.is_number(warning_percent)
        ValueChecker.is_number(critical_percent)
        self.__check_partitions.append((id, path, warning_percent, critical_percent))

        return self

    def check_sudoers(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_sudoers = enabled

        return self

    def is_checking_sudoers(self):
        return self.__check_sudoers

    def check_normal_users(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_normal_users = enabled

        return self

    def is_checking_normal_users(self):
        return self.__check_normal_users

    def check_wheel(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__check_wheel = enabled

        return self

    def is_checking_wheel(self):
        return self.__check_wheel

    def add_sudoers(self, username):
        ValueChecker.is_string(username)
        self.__sudoers.append(username)

        return self

    def add_normal_user(self, username):
        ValueChecker.is_string(username)
        self.__additional_users.append(username)

        return self

    def add_notification(self, notification):
        # todo type check
        self.__notifications.append(notification)
        return self

    def get_notification(self):
        return self.__notifications

    def apply_notification_to_check(self, check):
        # todo type check
        for notification in self.__notifications:
            check.add_notification(notification)
        return self

    def set_check_type(self, type):
        # todo type check
        self.__check_type = type
        return self

    def create_running_check(self, name, command, server):
        check = CheckProcs.create('running_proc_' + name + '_' + server.get_id()) \
            .set_check_type(self.__check_type) \
            .set_critical_range('1:') \
            .set_command(command) \
            .add_service_group(ServiceGroup.create(name))
        self.apply_notification_to_check(check)
        server.add_check(check)

        return check

    def create_running_check_arguments(self, name, argument, server):
        check = CheckProcs.create('running_proc_' + name + '_' + server.get_id()) \
            .set_check_type(self.__check_type) \
            .set_critical_range('1:') \
            .set_argument(argument) \
            .add_service_group(ServiceGroup.create(name))
        self.apply_notification_to_check(check)
        server.add_check(check)

        return check

    def apply(self):
        for server in self.__servers:
            if True is self.__check_apt:
                check = CheckApt.create('apt_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_yum:
                check = CheckYum.create('yum_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_load:
                check = CheckLoad.create('load_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_ntp_time:
                check = CheckNTPTime.create('ntp_time_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_swap:
                check = CheckSWAP.create('swap_' + server.get_id()) \
                    .set_check_type(self.__check_type)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_users:
                check = CheckUsers.create('users_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_sshd_security:
                check = CheckSSHDSecurity.create('sshd_security_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_sshd_running:
                self.create_running_check('sshd', 'sshd', server)

            if True is self.__check_mysqld_running:
                check = self.create_running_check('mysql', 'mysqld', server)
                check.add_service_group(ServiceGroup.create('database'))

            if True is self.__check_postgres_running:
                check = self.create_running_check('postgres', 'postgres', server)
                check.add_service_group(ServiceGroup.create('database'))

            if True is self.__check_cron_running:
                self.create_running_check('cron', 'cron', server)

            if True is self.__check_crond_running:
                self.create_running_check('cron', 'crond', server)

            if True is self.__check_rsyslogd_running:
                self.create_running_check('rsyslogd', 'rsyslogd', server)

            if True is self.__check_nginx_running:
                check = self.create_running_check('nginx', 'nginx', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_apache_running:
                check = self.create_running_check('apache', 'apache2', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_httpd_running:
                check = self.create_running_check('httpd', 'httpd', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_tomcat_running:
                check = self.create_running_check('tomcat', 'tomcat', server)
                check.add_service_group(ServiceGroup.create('webserver'))

            if True is self.__check_php_fpm_running:
                self.create_running_check('php_fpm', 'php-fpm', server)

            if True is self.__check_freshclam_running:
                check = self.create_running_check('freshclam', 'freshclam', server)
                check.add_service_group(ServiceGroup.create('security'))
                check.add_service_group(ServiceGroup.create('antivirus'))

            if True is self.__check_clamd_running:
                check = self.create_running_check('clamd', 'clamd', server)
                check.add_service_group(ServiceGroup.create('security'))
                check.add_service_group(ServiceGroup.create('antivirus'))

            if True is DefaultLocalChecks.is_checking_postfix_running(self):
                check = self.create_running_check_arguments('postfix', 'postfix', server)
                check.add_service_group(ServiceGroup.create('mail'))

            if True is self.__check_sudoers:
                check = CheckGroupMembers.create('sudoers_group_members_' + server.get_id()) \
                    .set_check_type(self.__check_type) \
                    .add_service_group(ServiceGroup.create('sudoers'))
                for user in self.__sudoers:
                    check.append_user(user)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_wheel:
                check = CheckGroupMembers.create('wheel_group_members_' + server.get_id()) \
                    .set_group('wheel') \
                    .set_check_type(self.__check_type) \
                    .add_service_group(ServiceGroup.create('sudoers'))
                for user in self.__sudoers:
                    check.append_user(user)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_normal_users:
                check = CheckExistingUsers.create('existing_users_' + server.get_id()) \
                    .set_check_type(self.__check_type)
                for user in self.__sudoers:
                    check.append_existing_users(user)
                for user in self.__additional_users:
                    check.append_existing_users(user)

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_ufw:
                check = CheckUFWStatus.create('ufw_status_' + server.get_id()) \
                    .set_incoming(self.__ufw_defaults[0]) \
                    .set_outgoing(self.__ufw_defaults[1]) \
                    .set_routing(self.__ufw_defaults[2]) \
                    .set_check_type(self.__check_type)
                for policy in self.__ufw_rules:
                    check.add_rule(policy[0], policy[1], policy[2])

                self.apply_notification_to_check(check)
                server.add_check(check)

            if True is self.__check_disk:
                if len(self.__check_partitions) == 0:
                    check = CheckDisk.create('disk_' + server.get_id()) \
                        .set_check_type(self.__check_type)
                    self.apply_notification_to_check(check)
                    server.add_check(check)
                else:
                    for config in self.__check_partitions:
                        check = CheckDisk.create('disk_' + config[0] + '_' + server.get_id())
                        check.set_display_name(check.get_display_name() + ' ' + config[0]) \
                            .set_check_type(self.__check_type) \
                            .set_partition(config[1]) \
                            .set_warning_percent(config[2]) \
                            .set_critical_percent(config[3])
                        self.apply_notification_to_check(check)
                        server.add_check(check)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.CheckDNSSECExpire import CheckDNSSECExpire
from icinga2confgen.Checks.MonitoringPlugins.CheckDig import CheckDig
from icinga2confgen.Groups.ServiceGroup import ServiceGroup


class DomainCheck:

    def __init__(self, domain_configs=[], checkserver=[], notifications=[]):
        self.__notifications = notifications
        self.__domain_configs = domain_configs
        self.__checkserver = checkserver

    def add_domainconfig(self, config):
        self.__domain_configs.append(config)

    def add_checkserver(self, checkserver):
        self.__checkserver.append(checkserver)

    def apply_notification_to_check(self, check):
        for notification in self.__notifications:
            check.add_notification(notification)

    def apply(self):

        for checkserver in self.__checkserver:

            for config in self.__domain_configs:
                domain = config[0]
                ipv4 = config[1]
                ipv6 = config[2]
                dnssec = config[3]
                base_id = ''.join(e for e in domain if e.isalnum())

                if True is dnssec:
                    dnssec_check = CheckDNSSECExpire.create('dnssec_expiry_' + base_id)
                    dnssec_check.add_service_group(ServiceGroup.create('dnssec')) \
                        .set_display_name(dnssec_check.get_display_name() + ' ' + domain) \
                        .set_zone(domain)

                    self.apply_notification_to_check(dnssec_check)

                    checkserver.add_check(dnssec_check)

                if None is not ipv4:
                    ipv4_check = CheckDig.create('domain_address_ipv4_' + base_id)
                    ipv4_check.set_record_type('A') \
                        .set_question(domain) \
                        .set_expected_address(ipv4) \
                        .set_display_name(ipv4_check.get_display_name() + ' ' + domain)

                    self.apply_notification_to_check(ipv4_check)
                    checkserver.add_check(ipv4_check)

                if None is not ipv6:
                    ipv6_check = CheckDig.create('domain_address_ipv6_' + base_id)
                    ipv6_check.set_record_type('AAAA') \
                        .set_question(domain) \
                        .set_expected_address(ipv6) \
                        .set_display_name(ipv6_check.get_display_name() + ' ' + domain)
                    self.apply_notification_to_check(ipv6_check)

                    checkserver.add_check(ipv6_check)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.UserGroup import UserGroup
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class User:

    def __init__(self, id):
        self.__id = id
        self.__display_name = None
        self.__enable_notifications = True
        self.__states = ['OK', 'Warning', 'Critical', 'Unknown', 'Down']
        self.__allowed_states = ['OK', 'Warning', 'Critical', 'Unknown', 'Down']
        self.__types = [
            'Problem', 'Acknowledgement', 'Recovery', 'Custom', 'FlappingStart',
            'FlappingEnd', 'DowntimeStart', 'DowntimeEnd', 'DowntimeRemoved'
        ]
        self.__allowed_types = [
            'Problem', 'Acknowledgement', 'Recovery', 'Custom', 'FlappingStart',
            'FlappingEnd', 'DowntimeStart', 'DowntimeEnd', 'DowntimeRemoved'
        ]
        self.__phone = None
        self.__pager = None
        self.__email = []
        self.__pager = None
        self.__groups = []
        self.__vars = []

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        user = None if force_create else ConfigBuilder.get_user(id)
        if None is user:
            user = User(id)
            ConfigBuilder.add_user(id, user)

        return user

    def get_id(self):
        return self.__id

    def set_display_name(self, display_name):
        ValueChecker.is_string(display_name)
        self.__display_name = display_name
        return self

    def get_display_name(self):
        return self.__display_name

    def add_email(self, email):
        ValueChecker.is_string(email)
        self.__email.append(email)
        return self

    def remove_email(self, email):
        ValueChecker.is_string(email)
        self.__email.remove(email)
        return self

    def get_email(self):
        return self.__email

    def set_pager(self, pager):
        ValueChecker.is_string(pager)
        self.__pager = pager
        return self

    def get_pager(self):
        return self.__pager

    def set_phone(self, phone):
        ValueChecker.is_string(phone)
        self.__phone = phone
        return self

    def get_phone(self):
        return self.__phone

    def set_types(self, types):
        for type in types:
            if type not in self.__allowed_types:
                raise Exception('Type ' + type + ' is not allowed')
        self.__types = types
        return self

    def get_types(self):
        return self.__types

    def set_states(self, states):
        for state in states:
            if state not in self.__allowed_states:
                raise Exception('State ' + state + ' is not allowed')
        self.__states = states
        return self

    def get_states(self):
        return self.__states

    def add_group(self, group):

        if isinstance(group, UserGroup):
            self.__groups.append(group)

        elif isinstance(group, str):
            group = ConfigBuilder.get_usergroup(group)
            if None is group:
                raise Exception('UserGroup does not exist yet!')
            self.__groups.append(group)
        else:
            raise Exception('Can only add UserGroup or id of UserGroup!')

        return self

    def remove_group(self, group):

        if isinstance(group, UserGroup):
            self.__groups.remove(group)

        elif isinstance(group, str):
            group = ConfigBuilder.get_usergroup(group)
            self.__groups.remove(group)

        return self

    def get_groups(self):

        return self.__groups

    def add_var(self, key, value):

        ValueChecker.is_string(key)
        self.__vars.append((key, value))

        return self

    def set_enable_notifications(self, enable_notifications):
        ValueChecker.is_bool(enable_notifications)
        self.__enable_notifications = enable_notifications
        return self

    def get_enable_notifications(self):
        return self.__enable_notifications

    def validate(self):
        if None is self.__email:
            raise Exception('Email is required for User ' + self.get_id())

    def get_config(self):
        self.validate()

        config = 'object User "user_' + self.__id + '" {\n'
        config += ValueMapper.parse_var('vars.email_addresses', self.__email)
        config += ValueMapper.parse_var('pager', self.__pager)
        config += ValueMapper.parse_var('vars.phone', self.__phone)
        config += ValueMapper.parse_var('display_name', self.__display_name)
        config += ValueMapper.parse_var('enable_notifications', self.__enable_notifications)
        config += ValueMapper.parse_var('groups', self.__groups, value_prefix='usergroup_')
        config += ValueMapper.parse_var('states', self.__states)
        config += ValueMapper.parse_var('types', self.__types)

        for var in self.__vars:
            config += '  var.' + var[0] + ' = ' + ValueMapper.parse_value_for_var(var[1]) + '\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.


class NotificationCommand:

    def __init__(self, id):
        self.__id = id

    def get_id(self):
        return self.__id

    def validate(self):
        raise Exception("validate must be overridden in " + self.__id)

    def get_command_executable_host(self):
        raise Exception("get_command_executable_path_host must return command executable for host in " + self.__id)

    def get_command_executable_service(self):
        raise Exception("get_command_executable_service must return command executable for service in " + self.__id)

    def get_arguments_host(self):
        config = '{\n' + self.get_default_arguments_host() + '}\n'
        config += self.get_default_vars_host()

        return config

    def get_arguments_service(self):
        config = '{\n' + self.get_default_arguments_service() + '}\n'
        config += self.get_default_vars_service()

        return config

    def get_command_definition_host(self):
        return '[ "/etc/icinga2/scripts/' + self.get_command_executable_host() + '"]'

    def get_command_definition_service(self):
        return '[ "/etc/icinga2/scripts/' + self.get_command_executable_service() + '"]'

    def get_config(self):
        self.validate()
        config = 'object NotificationCommand "command_host_' + self.get_id() + '" {\n'
        config += '  command = ' + self.get_command_definition_host() + '\n'
        config += '  arguments = ' + self.get_arguments_host() + '\n'
        config += '}\n'
        config += 'object NotificationCommand "command_service_' + self.get_id() + '" {\n'
        config += '  command = ' + self.get_command_definition_service() + '\n'
        config += '  arguments = ' + self.get_arguments_service() + '\n'
        config += '}\n'

        return config

    def get_default_arguments_host(self):
        return """
    "-d" = {
      value = "$notification_date$"
      required = true
    }
    "-l" = {
      value = "$notification_hostname$"
      required = true
    }
    "-n" = {
      value = "$notification_hostdisplayname$"
      required = true
    }
    "-o" = {
      value = "$notification_serviceoutput$"
      required = true
    }
    "-s" = {
      value = "$notification_servicestate$"
      required = true
    }
    "-4" = {
      value = "$notification_address$"
      set_if = {{ macro("$notification_address$") != false }}
    }
    "-6" = {
      value = "$notification_address6$"
      set_if = {{ macro("$notification_address6$") != false }}
    }
    "-b" = {
      value = "$notification_author$"
      set_if = {{ macro("$notification_author$") != false }}
    }
    "-c" = {
      value = "$notification_comment$"
      set_if = {{ macro("$notification_comment$") != false }}
    }
    "-i" = {
      value = "$notification_icingaweb2url$"
      set_if = {{ macro("$notification_icingaweb2url$") != false }}
    }
    "-f" = {
      value = "$notification_from$"
      set_if = {{ macro("$notification_from$") != false }}
      description = "Set from icinga2confgen.address. Requires GNU mailutils (Debian/Ubuntu) or mailx (RHEL/SUSE)"
    }
    "-v" = {
      set_if = "$notification_logtosyslog$"
    }
"""

    def get_default_vars_host(self):
        return """
  vars += {
    notification_address = "$address$"
    notification_address6 = "$address6$"
    notification_author = "$notification.author$"
    notification_comment = "$notification.comment$"
    notification_date = "$icinga.long_date_time$"
    notification_hostname = "$host.name$"
    notification_hostdisplayname = "$host.display_name$"
    notification_serviceoutput = "$service.output$"
    notification_servicestate = "$service.state$"
  }
"""

    def get_default_arguments_service(self):
        config = self.get_default_arguments_host()
        config += """
    "-e" = {
      value = "$notification_servicename$"
      required = true
    }
    "-t" = {
      value = "$notification_type$"
      required = true
    }
    "-u" = {
      value = "$notification_servicedisplayname$"
      required = true
    }
"""
        return config

    def get_default_vars_service(self):
        config = self.get_default_vars_host()
        config += """
  vars += {
    notification_servicename = "$service.name$"
    notification_type = "$notification.type$"
    notification_servicedisplayname = "$service.display_name$"
  }
"""
        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
import inspect


class ValueMapper:

    @staticmethod
    def get_property_default_config(instance, class_name, command_name, prefix):

        attributes = inspect.getmembers(instance, lambda a: not (inspect.isroutine(a)))
        properties = [a for a in attributes if (a[0].startswith('_' + class_name + '__'))]
        config = ''
        for property in properties:
            if None is property[1]:
                continue
            config += '  vars.' + property[0].replace(
                '_' + class_name + '__',
                prefix + '_' + command_name + '_'
            ) + ' = ' + ValueMapper.parse_value_for_var(property[1]) + '\n'

        return config

    @staticmethod
    def parse_var(key, value, ignore_none_value=True, value_prefix=''):
        if ignore_none_value and None is value:
            return ''
        if isinstance(value, list):
            if 0 == len(value):
                return ''
            return '  ' + key + ' += ' + ValueMapper.parse_value_for_var(value, value_prefix) + '\n'

        return '  ' + key + ' = ' + ValueMapper.parse_value_for_var(value, value_prefix) + '\n'

    @staticmethod
    def parse_value_for_var(value, value_prefix=''):
        if True is value:
            return 'true'
        elif False is value:
            return 'false'

        elif isinstance(value, str):
            return '"' + value_prefix + value + '"'

        elif isinstance(value, int):
            return str(value)

        elif isinstance(value, list):
            arr = '[\n'
            for a in value:
                arr += '    ' + ValueMapper.parse_value_for_var(a, value_prefix) + ',\n'
            arr += '  ]'
            return arr
        elif callable(getattr(value, 'get_id', None)):
            return ValueMapper.parse_value_for_var(value_prefix + value.get_id())

        raise Exception('Cannot parse value ' + value)

    @staticmethod
    def canonicalize_for_id(raw):
        allowed_chars = ['.', '_', '-']
        return ''.join(e for e in raw if e.isalnum() or e in allowed_chars)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.Icinga2Confgen.ExistingUsersCommand import ExistingUsersCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckExistingUsers(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckExistingUsers', 'existing_users')
        self.__uid_min = None
        self.__uid_max = None
        self.__users = ["root"]
        self.__shell_filter = ["/bin/false", "/bin/sync", "/sbin/nologin", "/usr/sbin/nologin"]
        self.set_check_interval('3h')
        self.add_service_group(ServiceGroup.create('security'))
        self.add_service_group(ServiceGroup.create('existing_user'))

    def set_uid_min(self, uid_min):
        ValueChecker.is_string(uid_min)
        self.__uid_min = uid_min
        return self

    def get_uid_min(self):
        return self.__uid_min

    def set_uid_max(self, uid_max):
        ValueChecker.is_string(uid_max)
        self.__uid_max = uid_max
        return self

    def get_uid_max(self):
        return self.__uid_max

    def append_existing_users(self, user):
        ValueChecker.is_string(user)
        self.__users.append(user)
        return self

    def remove_existing_users(self, user):
        self.__users.remove(user)
        return self

    def get_existing_users(self):
        return self.__users

    def append_shell_filter(self, shell):
        ValueChecker.is_string(shell)
        self.__shell_filter.append(shell)
        return self

    def remove_shell_filter(self, shell):
        self.__shell_filter.remove(shell)
        return self

    def get_shell_filter(self):
        return self.__shell_filter

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckExistingUsers(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('existing_users'):
            ExistingUsersCommand.create('existing_users')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class TimePeriod:

    def __init__(self, id):
        self.__id = id
        self.__display_name = None
        self.__ranges = []

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        period = None if force_create else ConfigBuilder.get_time_period(id)
        if None is period:
            period = TimePeriod(id)
            ConfigBuilder.add_time_period(id, period)

        return period

    def get_id(self):
        return self.__id

    def set_display_name(self, display_name):
        ValueChecker.is_string(display_name)
        self.__display_name = display_name
        return self

    def get_display_name(self):
        return self.__display_name

    def add_period(self, day, range):
        ValueChecker.is_string(day)
        ValueChecker.is_string(range)
        self.__ranges.append((day, range))
        return self

    def remove_period(self, day, range):
        ValueChecker.is_string(day)
        ValueChecker.is_string(range)
        self.__ranges.remove((day, range))
        return self

    def get_config(self):
        config = 'object TimePeriod "time_period_' + self.__id + '" {\n'

        if None is not self.__display_name:
            config += '  display_name = "' + self.__display_name + '"\n'

        config += '  ranges = {\n'
        for range in self.__ranges:
            config += '    "' + range[0] + '" = "' + range[1] + '"\n'
        config += '  }\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class SSHTemplate:

    def __init__(self, id):
        self.__id = id
        self.__host = None
        self.__identityfile = None
        self.__user = 'icinga'
        self.__port = 22
        self.__timeout = 30
        self.__plugin_dir = '/usr/lib/nagios/plugins/'

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        template = None if force_create else ConfigBuilder.get_ssh_template(id)
        if None is template:
            template = SSHTemplate(id)
            ConfigBuilder.add_ssh_template(id, template)

        return template

    def get_id(self):
        return self.__id

    def set_hostname(self, hostname):
        ValueChecker.is_string(hostname)
        self.__host = hostname
        return self

    def get_hostname(self):
        return self.__host

    def set_plugin_dir(self, plugin_dir):
        ValueChecker.is_string(plugin_dir)
        self.__host = plugin_dir
        return self

    def get_plugin_dir(self):
        return self.__host

    def set_user(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user(self):
        return self.__user

    def set_identity_file(self, identity_file):
        ValueChecker.is_string(identity_file)
        self.__identityfile = identity_file
        return self

    def get_identity_file(self):
        return self.__identityfile

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def get_config(self):
        config = 'template Host "sshtemplate_' + self.__id + '" {\n'
        config += ValueMapper.get_property_default_config(self, 'SSHTemplate', 'overssh', 'command')
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.NagiosPlugins.YumCommand import YumCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckYum(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckYum', 'yum')
        self.__timeout = 30
        self.__all_updates = False
        self.__warn_any_update = True
        self.__cache_only = False
        self.__no_warn_on_lock = False
        self.__config = None
        self.__repo_enabled = None
        self.__repo_disabled = None
        self.__plugin_disabled = None
        self.set_check_interval('1h')
        self.add_service_group(ServiceGroup.create('updates'))
        self.add_service_group(ServiceGroup.create('yum'))

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_all_updates(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__all_updates = enabled
        return self

    def get_all_updates(self):
        return self.__all_updates

    def set_cache_only(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__cache_only = enabled
        return self

    def get_cache_only(self):
        return self.__cache_only

    def set_no_warn_on_lock(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__no_warn_on_lock = enabled
        return self

    def get_no_warn_on_lock(self):
        return self.__no_warn_on_lock

    def set_warn_any_update(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__warn_any_update = enabled
        return self

    def get_warn_any_update(self):
        return self.__warn_any_update

    def set_yum_config(self, config):
        ValueChecker.is_string(config)
        self.__config = config
        return self

    def get_yum_config(self):
        return self.__config

    def set_repo_enabled(self, repo_enabled):
        ValueChecker.is_string(repo_enabled)
        self.__repo_enabled = repo_enabled
        return self

    def get_repo_enabled(self):
        return self.__repo_enabled

    def set_repo_disabled(self, repo_disabled):
        ValueChecker.is_string(repo_disabled)
        self.__repo_disabled = repo_disabled
        return self

    def get_repo_disabled(self):
        return self.__repo_disabled

    def set_plugin_disabled(self, plugin_disabled):
        ValueChecker.is_string(plugin_disabled)
        self.__plugin_disabled = plugin_disabled
        return self

    def get_plugin_disabled(self):
        return self.__plugin_disabled

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckYum(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('yum'):
            YumCommand.create('yum')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Commands.Command import Command
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class NNTPSCommand(Command):

    def __init__(self, id):
        Command.__init__(self, id)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_command(id)
        if None is command:
            command = NNTPSCommand(id)
            ConfigBuilder.add_command(id, command)

        return command

    def get_command(self):
        return 'check_nntps'

    def get_arguments(self):
        config = """{
    "-H" = {
      value = "$command_nntps_host$"
      required = true
    }
    "-p" = {
      value = "$command_nntps_port$"
      required = true
    }
    "-4" = {
      set_if = "$command_nntps_ipv4$"
    }
    "-6" = {
      set_if = "$command_nntps_ipv6$"
    }
    "-E" = {
      set_if = "$command_nntps_escape$"
    }
    "-s" = {
      value = "$command_nntps_send$"
      set_if = {{ macro("$command_nntps_send$") != false }}
    }
    "-e" = {
      value = "$command_nntps_expect$"
      set_if = {{ macro("$command_nntps_expect$") != false }}
    }
    "-A" = {
      set_if = "$command_nntps_all$"
    }
    "-q" = {
      value = "$command_nntps_quit$"
      set_if = {{ macro("$command_nntps_quit$") != false }}
    }
    "-r" = {
      value = "$command_nntps_refuse_state$"
      set_if = {{ macro("$command_nntps_refuse_state$") != false }}
    }
    "-M" = {
      value = "$command_nntps_mismatch_state$"
      set_if = {{ macro("$command_nntps_mismatch_state$") != false }}
    }
    "-j" = {
      set_if = "$command_nntps_jail$"
    }
    "-m" = {
      value = "$command_nntps_maxbytes$"
      set_if = {{ macro("$command_nntps_maxbytes$") != false }}
    }
    "-d" = {
      value = "$command_nntps_delay$"
      set_if = {{ macro("$command_nntps_delay$") != false }}
    }
    "-D" = {
      value = "$command_nntps_cert_warning$,$command_nntps_cert_critical$"
      set_if = {{ macro("$command_nntps_cert$") != false }}
    }
    "-S" = {
      set_if = "$command_nntps_use_ssl$"
    }
    "--sni" = {
      value = "$command_nntps_sni$"
      set_if = {{ macro("$command_nntps_sni$") != false }}
    }
    "-w" = {
      value = "$command_nntps_warning_time$"
      set_if = {{ macro("$command_nntps_warning_time$") != false }}
    }
    "-c" = {
      value = "$command_nntps_critical_time$"
      set_if = {{ macro("$command_nntps_critical_time$") != false }}
    }
    "-t" = {
      value = "$command_nntps_timeout$"
      set_if = {{ macro("$command_nntps_timeout$") != false }}
    }
  }
"""

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Downtimes.DefaultScheduledDowntimes import ScheduledDowntime
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.Notification.Notification import Notification
from icinga2confgen.Servers.Zone import Zone
from icinga2confgen.Utils.DefaultNames import get_default_check_name
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class Check:

    def __init__(self, id, class_name, command_name):
        self.__command_name = command_name
        self.__class_name = class_name
        self.__display_name = get_default_check_name(id, command_name)
        self.__id = id
        self.__service_groups = []
        self.__check_type = "local"
        self.__notifications = []
        self.__downtimes = []
        self.__allowed_check_types = ["local", "ssh"]
        self.__max_check_attempts = 3
        self.__check_interval = '1m'
        self.__retry_interval = '15s'
        self.__enable_perfdata = True
        self.__command_endpoint = None
        self.__override_endpoint = False
        self.__zone = None
        self.__override_zone = False

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = Check(id, 'Check', 'check')
            ConfigBuilder.add_check(id, check)

        return check

    def validate(self):
        raise Exception('Each check must override validate method')

    def add_service_group(self, group):
        if isinstance(group, ServiceGroup):
            self.__service_groups.append(group.get_id())
        elif isinstance(group, str):
            if None is ConfigBuilder.get_servicegroup(group):
                raise Exception('ServiceGroup does not exist yet!')
            self.__service_groups.append('servicegroup_' + group)
        else:
            raise Exception('Can only add Servicegroup or id of Servicegroup!')

        return self

    def set_zone(self, zone):
        if isinstance(zone, Zone):
            self.__zone = zone
            self.__override_zone = True
        elif isinstance(zone, str):
            zone = ConfigBuilder.get_zone(zone)
            if None is zone:
                raise Exception('Zone does not exist yet!')
            self.__zone = zone
            self.__override_zone = True
        else:
            raise Exception('Can only add Zone or id of Zone!')
        return self

    def get_zone(self):
        return self.__zone

    def set_endpoint_name(self, name):
        ValueChecker.is_string(name)
        self.__override_endpoint = True
        self.__command_endpoint = name
        return self

    def get_endpoint_name(self):
        return self.__command_endpoint

    def add_notification(self, notification):
        if isinstance(notification, Notification):
            self.__notifications.append(notification)
        elif isinstance(notification, str):
            notification = ConfigBuilder.get_notification(notification)
            if None is notification:
                raise Exception('Notification does not exist yet!')

            self.__notifications.append(notification)
        else:
            raise Exception('Can only add Notification or id of Notification!')

        return self

    def add_downtime(self, downtime):
        if isinstance(downtime, ScheduledDowntime):
            self.__downtimes.append(downtime.get_id())
        elif isinstance(downtime, str):
            if None is ConfigBuilder.get_downtime(downtime):
                raise Exception('Downtime does not exist yet!')
            self.__downtimes.append(downtime)
        else:
            raise Exception('Can only add Downtime or id of Downtime!')

        return self

    def get_service_group_ids(self):

        return self.__service_groups

    def get_id(self):
        return self.__id

    def set_check_type(self, type):
        if type in self.__allowed_check_types:
            self.__check_type = type
            return self
        raise Exception("Checktype must be " + ' or '.join(self.__allowed_check_types))

    def get_check_type(self):
        return self.__check_type

    def set_max_check_attempts(self, max_check_attempts):
        ValueChecker.is_number(max_check_attempts)
        self.__max_check_attempts = max_check_attempts
        return self

    def get_max_check_attempts(self):
        return self.__max_check_attempts

    def set_check_interval(self, check_interval):
        ValueChecker.is_string(check_interval)
        self.__check_interval = check_interval
        return self

    def get_check_interval(self):
        return self.__check_interval

    def set_retry_interval(self, retry_interval):
        ValueChecker.is_string(retry_interval)
        self.__retry_interval = retry_interval
        return self

    def get_retry_interval(self):
        return self.__retry_interval

    def set_enable_perfdata(self, enable_perfdata):
        ValueChecker.is_bool(enable_perfdata)
        self.__enable_perfdata = enable_perfdata
        return self

    def set_display_name(self, display_name):
        ValueChecker.is_string(display_name)
        self.__display_name = display_name
        return self

    def get_display_name(self):
        return self.__display_name

    def get_custom_definitions(self):
        return []

    def get_config(self):
        self.validate()

        config = 'apply Service "check_' + self.get_id() + '" {\n'
        config += '  check_command = "command_' + self.__command_name + '_' + self.__check_type + '"\n'
        config += self.get_property_default_config()
        config += self.get_custom_property_config()
        config += self.get_group_config()
        config += self.get_notification_config()
        config += self.get_downtime_config()
        config += self.get_check_config()
        config += '  assign where "check_' + self.get_id() + '" in host.vars.checks\n'
        config += '}\n'

        return config

    def get_group_config(self):

        return ValueMapper.parse_var('groups', self.__service_groups, value_prefix='servicegroup_')

    def get_notification_config(self):

        return ValueMapper.parse_var('vars.notification', self.__notifications, value_prefix='notification_')

    def get_check_config(self):
        config = '  max_check_attempts = ' + str(self.__max_check_attempts) + '\n'
        config += '  check_interval = ' + self.__check_interval + '\n'
        config += '  retry_interval = ' + self.__retry_interval + '\n'
        config += ValueMapper.parse_var('enable_perfdata', self.__enable_perfdata)
        config += ValueMapper.parse_var('display_name', self.__display_name)
        if self.__override_endpoint:
            config += '  command_endpoint = "' + self.__command_endpoint + '"\n'
        else:
            config += '  command_endpoint = host.vars.endpoint_name\n'
        if self.__override_zone:
            config += '  zone = "' + self.__zone.get_id() + '"\n'
        else:
            config += '  zone = host.vars.zone_name\n'

        return config

    def get_downtime_config(self):
        return ValueMapper.parse_var('downtime', self.__downtimes, value_prefix='downtime_')

    def get_custom_property_config(self):
        config = ''
        for line in self.get_custom_definitions():
            config += '  ' + line + '\n'

        return config

    def get_property_default_config(self):

        return ValueMapper.get_property_default_config(self, self.__class_name, self.__command_name, 'command')



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.ProcsCommand import ProcsCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckProcs(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckProcs', 'procs')
        self.__warning_range = None
        self.__critical_range = None
        self.__metric = None
        self.__timeout = 10
        self.__traditional = False
        self.__state = None
        self.__pid = None
        self.__vsz = None
        self.__user = None
        self.__argument = None
        self.__argument_ereg = None
        self.__command = None
        self.__only_non_kernel = False
        self.add_service_group(ServiceGroup.create('procs'))
        self.add_service_group(ServiceGroup.create('system_health'))

    def set_warning_range(self, warning_range):
        ValueChecker.is_string(warning_range)
        self.__warning_range = warning_range
        return self

    def get_warning_range(self):
        return self.__warning_range

    def set_critical_range(self, critical_range):
        ValueChecker.is_string(critical_range)
        self.__critical_range = critical_range
        return self

    def get_critical_range(self):
        return self.__critical_range

    def set_metric(self, metric):
        ValueChecker.is_string(metric)
        self.__metric = metric
        return self

    def get_metric(self):
        return self.__metric

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    def set_traditional(self, traditional):
        ValueChecker.is_bool(traditional)
        self.__traditional = traditional
        return self

    def get_traditional(self):
        return self.__traditional

    def set_state(self, state):
        ValueChecker.is_string(state)
        self.__state = state
        return self

    def get_state(self):
        return self.__state

    def set_pid(self, pid):
        ValueChecker.is_string(pid)
        self.__pid = pid
        return self

    def get_pid(self):
        return self.__pid

    def set_vsz(self, vsz):
        ValueChecker.is_string(vsz)
        self.__vsz = vsz
        return self

    def get_vsz(self):
        return self.__vsz

    def set_user_of_threads(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user_of_threads(self):
        return self.__user

    def set_argument(self, argument):
        ValueChecker.is_string(argument)
        self.__argument = argument
        return self

    def get_argument(self):
        return self.__argument

    def set_argument_ereg(self, argument_ereg):
        ValueChecker.is_string(argument_ereg)
        self.__argument_ereg = argument_ereg
        return self

    def get_argument_ereg(self):
        return self.__argument_ereg

    def set_command(self, command):
        ValueChecker.is_string(command)
        self.__command = command
        return self

    def get_command(self):
        return self.__command

    def set_only_non_kernel(self, only_non_kernel):
        ValueChecker.is_bool(only_non_kernel)
        self.__only_non_kernel = only_non_kernel
        return self

    def get_only_non_kernel(self):
        return self.__only_non_kernel

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckProcs(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('procs'):
            ProcsCommand.create('procs')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.MonitoringPlugins.CheckHttp import CheckHttp
from icinga2confgen.Utils.DefaultWebserverChecks import DefaultWebserverChecks
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class DefaultGitChecks(DefaultWebserverChecks):

    def __init__(self, vhostconfig=[], servers=[], checkserver=[], notifications=[]):
        DefaultWebserverChecks.__init__(self, vhostconfig, servers, checkserver, notifications)
        self.__validate_deny_git = True
        self.__validate_deny_gitignore = True
        self.__inherit = True

    def set_inherit(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__inherit = enabled

        return self

    def is_inherit(self):
        return self.__inherit

    def validate_deny_git(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_git = enabled

        return self

    def is_validating_deny_git(self):
        return self.__validate_deny_git

    def validate_deny_gitignore(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_gitignore = enabled

        return self

    def is_validating_deny_gitignore(self):
        return self.__validate_deny_gitignore

    def apply(self):
        if self.__inherit:
            DefaultWebserverChecks.apply(self)

        for config in DefaultWebserverChecks.get_vhostconfigs(self):
            service_baseid = config[0]
            domain = config[1]

            for checkserver in DefaultWebserverChecks.get_checkservers(self):
                for server in DefaultWebserverChecks.get_servers(self):
                    base_id = service_baseid + '_' + server.get_id() + '_' + ValueMapper.canonicalize_for_id(domain)
                    server_ipv4 = server.get_ipv4()
                    server_ipv6 = server.get_ipv6()

                    if None is server_ipv4 and None is server_ipv6:
                        raise Exception('It is required to set the ipv4 or ipv6 on the server with id "' +
                                        server.get_id() + '", before you can apply this checks!')

                    if True is self.__validate_deny_git:
                        if None is not server_ipv4:
                            git_check = CheckHttp.create('web_access_deny_gitdir_ipv4_' + base_id)
                            git_check.set_ip(server_ipv4) \
                                .set_vhost(domain) \
                                .set_uri('/.git/') \
                                .set_ssl(True) \
                                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                                .set_expect('40') \
                                .set_check_interval('6h') \
                                .set_display_name(git_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(git_check)

                            checkserver.add_check(git_check)

                        if None is not server_ipv6:
                            git_check = CheckHttp.create('web_access_deny_gitdir_ipv6_' + base_id)
                            git_check.set_ip(server_ipv6) \
                                .set_vhost(domain) \
                                .set_uri('/.git/') \
                                .set_ssl(True) \
                                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                                .set_expect('40') \
                                .set_check_interval('6h') \
                                .set_display_name(git_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(git_check)

                            checkserver.add_check(git_check)

                    if True is self.__validate_deny_gitignore:
                        if None is not server_ipv4:
                            gitignore_check = CheckHttp.create('web_access_deny_gitignore_ipv4_' + base_id)
                            gitignore_check.set_ip(server_ipv4) \
                                .set_vhost(domain) \
                                .set_uri('/.gitignore') \
                                .set_ssl(True) \
                                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                                .set_expect('40') \
                                .set_check_interval('6h') \
                                .set_display_name(gitignore_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(git_check)

                            checkserver.add_check(gitignore_check)

                        if None is not server_ipv6:
                            gitignore_check = CheckHttp.create('web_access_deny_gitignore_upv6_' + base_id)
                            gitignore_check.set_ip(server_ipv6) \
                                .set_vhost(domain) \
                                .set_uri('/.gitignore') \
                                .set_ssl(True) \
                                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                                .set_expect('40') \
                                .set_check_interval('6h') \
                                .set_display_name(gitignore_check.get_display_name() + ' ' + domain)
                            self.apply_notification_to_check(git_check)

                            checkserver.add_check(gitignore_check)



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.MySQLCommand import MySQLCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckMySQL(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckMySQL', 'mysql')
        self.__host = '127.0.0.1'
        self.__port = 3306
        self.__ignore_auth = False
        self.__socket = None
        self.__database = None
        self.__file = None
        self.__group = None
        self.__user = None
        self.__password = None
        self.__check_slave = False
        self.__slave_warning = None
        self.__slave_critical = None
        self.__use_ssl = False
        self.__ssl_ciphers = None
        self.__ca_cert = None
        self.__ca_dir = None
        self.__cert = None
        self.__key = None
        self.add_service_group(ServiceGroup.create('mysql'))
        self.add_service_group(ServiceGroup.create('database'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_ignore_auth(self, ignore_auth):
        ValueChecker.is_bool(ignore_auth)
        self.__ignore_auth = ignore_auth
        return self

    def get_ignore_auth(self):
        return self.__ignore_auth

    def set_socket(self, socket):
        ValueChecker.is_string(socket)
        self.__socket = socket
        return self

    def get_socket(self):
        return self.__socket

    def set_database(self, database):
        ValueChecker.is_string(database)
        self.__database = database
        return self

    def get_database(self):
        return self.__database

    def set_file(self, file):
        ValueChecker.is_string(file)
        self.__file = file
        return self

    def get_file(self):
        return self.__file

    def set_group(self, group):
        ValueChecker.is_string(group)
        self.__group = group
        return self

    def get_group(self):
        return self.__group

    def set_user(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user(self):
        return self.__user

    def set_password(self, password):
        ValueChecker.is_string(password)
        self.__password = password
        return self

    def get_password(self):
        return self.__password

    def set_check_slave(self, check_slave):
        ValueChecker.is_bool(check_slave)
        self.__check_slave = check_slave
        return self

    def get_check_slave(self):
        return self.__check_slave

    def set_slave_warning(self, slave_warning):
        ValueChecker.is_string(slave_warning)
        self.__slave_warning = slave_warning
        return self

    def get_slave_warning(self):
        return self.__slave_warning

    def set_slave_critical(self, slave_critical):
        ValueChecker.is_string(slave_critical)
        self.__slave_critical = slave_critical
        return self

    def get_slave_critical(self):
        return self.__slave_critical

    def set_use_ssl(self, use_ssl):
        ValueChecker.is_bool(use_ssl)
        self.__use_ssl = use_ssl
        return self

    def get_use_ssl(self):
        return self.__use_ssl

    def set_ssl_ciphers(self, ssl_ciphers):
        ValueChecker.is_string(ssl_ciphers)
        self.__ssl_ciphers = ssl_ciphers
        return self

    def get_ssl_ciphers(self):
        return self.__ssl_ciphers

    def set_ca_cert(self, ca_cert):
        ValueChecker.is_string(ca_cert)
        self.__ca_cert = ca_cert
        return self

    def get_ca_cert(self):
        return self.__ca_cert

    def set_ca_dir(self, ca_dir):
        ValueChecker.is_string(ca_dir)
        self.__ca_dir = ca_dir
        return self

    def get_ca_dir(self):
        return self.__ca_dir

    def set_cert(self, cert):
        ValueChecker.is_string(cert)
        self.__cert = cert
        return self

    def get_cert(self):
        return self.__cert

    def set_key(self, key):
        ValueChecker.is_string(key)
        self.__key = key
        return self

    def get_key(self):
        return self.__key

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckMySQL(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('mysql'):
            MySQLCommand.create('mysql')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.RPCCommand import RPCCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckRPC(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckRPC', 'rpc')
        self.__host = None
        self.__command = None
        self.__port = None
        self.__version = None
        self.add_service_group(ServiceGroup.create('rpc'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_command(self, command):
        ValueChecker.is_string(command)
        self.__command = command
        return self

    def get_command(self):
        return self.__command

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_version(self, version):
        ValueChecker.is_string(version)
        self.__version = version
        return self

    def get_version(self):
        return self.__version

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckRPC(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('rpc'):
            RPCCommand.create('rpc')

        return check

    def validate(self):
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())
        if None is self.__command:
            raise Exception('You have to specify a command for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.Icinga2Confgen.UFWStatusCommand import UFWStatusCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckUFWStatus(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckUFWStatus', 'ufw_status')
        self.__status = None
        self.__warninactive = None
        self.__logging = None
        self.__loggingpolicy = None
        self.__incoming = None
        self.__outgoing = None
        self.__routing = None
        self.__rule = []
        self.set_check_interval('6h')
        self.add_service_group(ServiceGroup.create('security'))
        self.add_service_group(ServiceGroup.create('ufw'))
        self.add_service_group(ServiceGroup.create('firewall'))

    def set_status(self, status):
        ValueChecker.is_string(status)
        self.__status = status
        return self

    def get_status(self):
        return self.__status

    def set_warninactive(self, warninactive):
        ValueChecker.is_bool(warninactive)
        self.__warninactive = 'on' if warninactive else 'off'
        return self

    def get_warninactive(self):
        return True if 'on' == self.__warninactive else False

    def set_logging(self, logging):
        ValueChecker.is_string(logging)
        self.__logging = logging
        return self

    def get_logging(self):
        return self.__logging

    def set_incoming(self, incoming):
        ValueChecker.is_string(incoming)
        self.__incoming = incoming
        return self

    def get_incoming(self):
        return self.__incoming

    def set_outgoing(self, outgoing):
        ValueChecker.is_string(outgoing)
        self.__outgoing = outgoing
        return self

    def get_outgoing(self):
        return self.__outgoing

    def set_routing(self, routing):
        ValueChecker.is_string(routing)
        self.__routing = routing
        return self

    def get_routing(self):
        return self.__routing

    def add_rule(self, policy_from, policy_to, policy_action):
        ValueChecker.is_string(policy_from)
        ValueChecker.is_string(policy_to)
        ValueChecker.is_string(policy_action)
        self.__rule.append(policy_from + "," + policy_to + ',' + policy_action)
        return self

    def remove_rule(self, policy_from, policy_to, policy_action):
        ValueChecker.is_string(policy_from)
        ValueChecker.is_string(policy_to)
        ValueChecker.is_string(policy_action)
        self.__rule.remove(policy_from + "," + policy_to + ',' + policy_action)
        return self

    def get_rule(self):
        return self.__rule

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckUFWStatus(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ufw_status'):
            UFWStatusCommand.create('ufw_status')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Servers.ServerTemplate import ServerTemplate
from icinga2confgen.Servers.Zone import Zone
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class Server(ServerTemplate):

    def __init__(self, id):
        ServerTemplate.__init__(self, id)
        self.__id = id
        self.__zone = Zone.create('master')
        self.__endpoint_name = None

    def get_id(self):
        return self.__id

    def set_endpoint_name(self, name):
        ValueChecker.is_string(name)
        self.__endpoint_name = name
        return self

    def get_endpoint_name(self):
        return self.__endpoint_name

    def set_zone(self, zone):
        if isinstance(zone, Zone):
            self.__zone = zone

        elif isinstance(zone, str):
            zone = ConfigBuilder.get_zone(zone)
            if None is zone:
                raise Exception('Zone does not exist yet!')
            self.__zone = zone
        else:
            raise Exception('Can only add Zone or id of Zone!')
        return self

    def get_zone(self):
        return self.__zone

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        server = None if force_create else ConfigBuilder.get_server(id)
        if None is server:
            server = Server(id)
            ConfigBuilder.add_server(id, server)

        return server

    def get_config(self):
        config = ServerTemplate.get_config(self)
        config += 'object Host "server_' + self.get_id() + '" {\n'
        config += '  import "servertemplate_' + ServerTemplate.get_id(self) + '"\n'
        config += '  vars.zone_name = "' + self.__zone.get_id() + '"\n'
        config += ValueMapper.parse_var('vars.endpoint_name', self.__endpoint_name)
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Commands.Command import Command
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class HttpCommand(Command):

    def __init__(self, id):
        Command.__init__(self, id)

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        command = None if force_create else ConfigBuilder.get_command(id)
        if None is command:
            command = HttpCommand(id)
            ConfigBuilder.add_command(id, command)

        return command

    def get_command(self):
        return 'check_http'

    def get_arguments(self):
        return """{
    "--hostname" = {
      value = "$command_http_vhost$"
    }
    "--IP-address" = {
      value = "$command_http_ip$"
    }
    "--port" = {
      value = "$command_http_port$"
      set_if = {{ macro("$command_http_port$") != false }}
    }
    "--use-ipv4" = {
      set_if = {{ macro("$command_http_v4$") != false }}
    }
    "--use-ipv6" = {
      set_if = "$command_http_v6$"
    }
    "-S" = {
      set_if = "$command_http_ssl$"
    }
    "--ssl" = {
      value = "$command_http_ssl_protocol$"
      set_if = {{ macro("$command_http_ssl_protocol$") != false }}
    }
    "--sni" = {
      set_if = "$command_http_sni$"
    }
    "--certificate" = {
      value = "$command_http_certificate_warning_days$,$command_http_certificate_critical_days$"
      set_if = {{ macro("$command_http_certificate$") != false }}
    }
    "--continue-after-certificate" = {
      set_if = "$command_http_continue_after_certificate$"
    }
    "--client-cert" = {
      value = "$command_http_client_cert$"
      set_if = {{ macro("$command_http_client_cert$") != false }}
    }
    "--private-key" = {
      value = "$command_http_client_cert_key$"
      set_if = {{ macro("$command_http_client_cert_key$") != false }}
    }
    "--expect" = {
      value = "$command_http_expect$"
      set_if = {{ macro("$command_http_expect$") != false }}
    }
    "--header-string" = {
      value = "$command_http_expect_header$"
      set_if = {{ macro("$command_http_expect_header$") != false }}
    }
    "--string" = {
      value = "$command_http_expect_content$"
      set_if = {{ macro("$command_http_expect_content$") != false }}
    }
    "--url" = {
      value = "$command_http_uri$"
    }
    "--post" = {
      value = "$command_http_post_data$"
      set_if = {{ macro("$command_http_post_data$") != false }}
    }
    "--method" = {
      value = "$command_http_method$"
      set_if = {{ macro("$command_http_method$") != false }}
    }
    "--no-body" = {
      set_if = "$command_http_no_body$"
    }
    "--max-age" = {
      value = "$command_http_max_age$"
      set_if = {{ macro("$command_http_max_age$") != false }}
    }
    "--content-type" = {
      value = "$command_http_content_type$"
      set_if = {{ macro("$command_http_content_type$") != false }}
    }
    "--linespan" = {
      set_if = "$command_http_linespan$"
    }
    "--regex" = {
      value = "$command_http_regex$"
      set_if = {{ macro("$command_http_regex$") != false }}
    }
    "--eregi" = {
      value = "$command_http_eregi$"
      set_if = {{ macro("$command_http_eregi$") != false }}
    }
    "--invert-regex" = {
      set_if = "$command_http_invert_regex$"
    }
    "--authorization" = {
      value = "$command_http_authorization_username$:$command_http_authorization_password$"
      set_if = {{ macro("$command_http_authorization$") != false }}
    }
    "--proxy-authorization" = {
      value = "$command_http_proxy_authorization_username$:$command_http_proxy_authorization_password$"
      set_if = {{ macro("$command_http_proxy_authorization$") != false }}
    }
    "--useragent" = {
      value = "$command_http_useragent$"
      set_if = {{ macro("$command_http_useragent$") != false }}
    }
    "--header" = {
      value = "$command_http_header$"
      set_if = {{ macro("$command_http_header$") != false }}
    }
    "--extended-perfdata" = {
      set_if = "$command_http_extended_perfdata$"
    }
    "--show-url" = {
      set_if = "$command_http_show_url$"
    }
    "--link" = {
      set_if = "$command_http_link$"
    }
    "--onredirect" = {
      value = "$command_http_onredirect$"
      set_if = "$command_http_onredirect$"
    }
    "--pagesize" = {
      value = "$command_http_pagesize_min$:$command_http_pagesize_max$"
      set_if = {{ macro("$command_http_pagesize$") != false }}
    }
    "--warning" = {
      value = "$command_http_warning$"
      set_if = {{ macro("$command_http_warning$") != false }}
    }
    "--critical" = {
      value = "$command_http_critical$"
      set_if = {{ macro("$command_http_critical$") != false }}
    }
    "--timeout" = {
      value = "$command_http_timeout$"
      set_if = {{ macro("$command_http_timeout$") != false }}
    }
  }
"""



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.DiskSMBCommand import DiskSMBCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckDiskSMB(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckDiskSMB', 'disk_smb')
        self.__host = None
        self.__warning = 85
        self.__critical = 95
        self.__share = None
        self.__workgroup = None
        self.__ip = None
        self.__user = None
        self.__password = None
        self.__port = 445
        self.add_service_group(ServiceGroup.create('disk'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_warning(self, warning):
        ValueChecker.is_number(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_number(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_share(self, share):
        ValueChecker.is_string(share)
        self.__share = share
        return self

    def get_share(self):
        return self.__share

    def set_workgroup(self, workgroup):
        ValueChecker.is_string(workgroup)
        self.__workgroup = workgroup
        return self

    def get_workgroup(self):
        return self.__workgroup

    def set_ip(self, ip):
        ValueChecker.is_string(ip)
        self.__ip = ip
        return self

    def get_ip(self):
        return self.__ip

    def set_user(self, user):
        ValueChecker.is_string(user)
        self.__user = user
        return self

    def get_user(self):
        return self.__user

    def set_password(self, password):
        ValueChecker.is_string(password)
        self.__password = password
        return self

    def get_password(self):
        return self.__password

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckDiskSMB(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('disk_smb'):
            DiskSMBCommand.create('disk_smb')

        return check

    def validate(self):
        if None is self.__share:
            raise Exception('You have to specify a share for ' + self.get_id())
        if None is self.__ip:
            raise Exception('You have to specify an ip for ' + self.get_id())
        if None is self.__user:
            raise Exception('You have to specify a user for ' + self.get_id())
        if None is self.__password:
            raise Exception('You have to specify a password for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.AptCommand import AptCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckApt(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckApt', 'apt')
        self.__timeout = 10
        self.__upgrade = None
        self.__dist_upgrade = None
        self.__no_upgrade = None
        self.__include = None
        self.__exclude = None
        self.__critical = None
        self.__only_critical = None
        self.__packages_warning = None
        self.__update = None
        self.set_check_interval('1h')
        self.add_service_group(ServiceGroup.create('updates'))
        self.add_service_group(ServiceGroup.create('apt'))

    def set_timeout(self, seconds):
        ValueChecker.is_number(seconds)
        self.__timeout = seconds
        return self

    def get_timeout(self):
        return self.__timeout

    def set_upgrade(self, opts):
        ValueChecker.is_string(opts)
        self.__upgrade = opts
        return self

    def get_upgrade(self):
        return self.__upgrade

    def set_dist_upgrade(self, opts):
        ValueChecker.is_string(opts)
        self.__dist_upgrade = opts
        return self

    def get_dist_upgrade(self):
        return self.__dist_upgrade

    def set_no_upgrade(self, opts):
        ValueChecker.is_string(opts)
        self.__no_upgrade = opts
        return self

    def get_no_upgrade(self):
        return self.__no_upgrade

    def set_include(self, expr):
        ValueChecker.is_string(expr)
        self.__include = expr
        return self

    def get_include(self):
        return self.__include

    def set_exclude(self, expr):
        ValueChecker.is_string(expr)
        self.__exclude = expr
        return self

    def get_exclude(self):
        return self.__exclude

    def set_critical(self, expr):
        ValueChecker.is_string(expr)
        self.__critical = expr
        return self

    def get_critical(self):
        return self.__critical

    def set_only_critical(self, enable):
        ValueChecker.is_bool(enable)
        self.__only_critical = enable
        return self

    def get_only_critical(self):
        return self.__only_critical

    def set_packages_warning(self, count):
        ValueChecker.is_number(count)
        self.__packages_warning = count
        return self

    def get_packages_warning(self):
        return self.__packages_warning

    def set_update(self, opts):
        ValueChecker.is_string(opts)
        self.__update = opts
        return self

    def get_update(self):
        return self.__update

    def get_custom_definitions(self):
        return []

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckApt(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('apt'):
            AptCommand.create('apt')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.HostGroup import HostGroup
from icinga2confgen.PackageManager.PackageManager import PackageManager
from icinga2confgen.ValueChecker import ValueChecker


class OS:

    def __init__(self, id):
        self.__id = id
        self.__os = None
        self.__distro = None
        self.__version = None
        self.__package_manager = []

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        os = None if force_create else ConfigBuilder.get_os(id)
        if None is os:
            os = OS(id)
            ConfigBuilder.add_os(id, os)

        return os

    def get_id(self):
        return self.__id

    def set_os(self, os):
        ValueChecker.is_string(os)
        HostGroup.create('hg_os_' + self.__id).set_display_name(os.capitalize())
        self.__os = os
        return self

    def get_os(self):
        return self.__os

    def append_package_manager(self, package_manager):

        if isinstance(package_manager, PackageManager):
            if package_manager not in self.__package_manager:
                self.__package_manager.append(package_manager)

        elif isinstance(package_manager, str):
            package_manager = ConfigBuilder.get_package_manager(package_manager)
            if None is package_manager:
                raise Exception('PackageManager does not exist yet!')

            return self.append_package_manager(package_manager)
        else:
            raise Exception('Can only add PackageManager or id of PackageManager!')

        return self

    def remove_package_manager(self, package_manager):

        if isinstance(package_manager, PackageManager):
            self.__package_manager.remove(package_manager.get_id())

        elif isinstance(package_manager, str):
            self.__package_manager.remove(package_manager)

        return self

    def get_package_manager(self):
        return self.__package_manager

    def set_version(self, version):
        ValueChecker.is_string(version)
        self.__version = version
        return self

    def get_version(self):
        return self.__version

    def set_distro(self, distro):
        ValueChecker.is_string(distro)
        HostGroup.create('hg_distro_' + distro).set_display_name(distro.capitalize())
        self.__distro = distro
        return self

    def get_distro(self):
        return self.__distro

    def validate(self):
        if None is self.__os:
            raise Exception('You have to specify OS for ' + self.get_id())
        if None is self.__version:
            raise Exception('You have to specify Version for ' + self.get_id())
        if None is self.__distro:
            raise Exception('You have to specify distro for ' + self.get_id())

    def get_config(self):
        self.validate()

        config = 'template Host "os_' + self.__id + '" {\n'
        for manager in self.__package_manager:
            config += '  import "packagemanager_' + manager.get_id() + '"\n'
        config += '  vars.os = "' + self.__os + '"\n'
        config += '  vars.version = "' + self.__version + '"\n'
        config += '  vars.distro = "' + self.__distro + '"\n'
        config += '  groups += ["hostgroup_hg_os_' + self.__id + '", "hostgroup_hg_distro_' + self.__distro + '"]\n'
        config += '}\n'

        return config



#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.User.User import User
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class ScheduledDowntime:

    def __init__(self, id):
        self.__id = id
        self.__comment = None
        self.__author = None
        self.__fixed = False
        self.__duration = None
        self.__child_options = None
        self.__ranges = []
        self.__type = None

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        period = None if force_create else ConfigBuilder.get_downtime(id)
        if None is period:
            period = ScheduledDowntime(id)
            ConfigBuilder.add_downtime(id, period)

        return period

    def get_id(self):
        return self.__id

    def set_comment(self, comment):
        ValueChecker.is_string(comment)
        self.__comment = comment
        return self

    def get_comment(self):
        return self.__comment

    def set_duration(self, duration):
        ValueChecker.is_string(duration)
        self.__duration = duration
        return self

    def get_duration(self):
        return self.__duration

    def set_author(self, author):

        if isinstance(author, User):
            self.__author = author.get_id()

        elif isinstance(author, str):
            if None is ConfigBuilder.get_user(author):
                raise Exception('User does not exist yet!')
            self.__author = author
        else:
            raise Exception('Can only add User or id of User!')

        return self

    def get_author(self):
        return self.__author

    def set_type(self, type):
        if type not in ['Service', 'Host']:
            raise Exception('Type must be Host or Service')
        self.__type = type
        return self

    def get_type(self):
        return self.__type

    def set_child_options(self, child_options):
        if child_options not in ['DowntimeNoChildren', 'DowntimeTriggeredChildren', 'DowntimeNonTriggeredChildren']:
            raise Exception(
                'child_options must be DowntimeNoChildren, DowntimeTriggeredChildren or DowntimeNonTriggeredChildren')
        self.__child_options = child_options
        return self

    def get_child_options(self):
        return self.__child_options

    def set_fixed(self, fixed):
        ValueChecker.is_bool(fixed)
        self.__fixed = fixed
        return self

    def get_fixed(self):
        return self.__fixed

    def add_period(self, day, range):
        ValueChecker.is_string(day)
        ValueChecker.is_string(range)
        self.__ranges.append((day, range))
        return self

    def remove_period(self, day, range):
        ValueChecker.is_string(day)
        ValueChecker.is_string(range)
        self.__ranges.remove((day, range))
        return self

    def validate(self):
        if None is self.__type:
            raise Exception('Type must be set for Downtime ' + self.__id)
        if None is self.__author:
            raise Exception('Author must be set for Downtime ' + self.__id)
        if None is self.__comment:
            raise Exception('Comment must be set for Downtime ' + self.__id)

    def get_config(self):

        config = 'apply ScheduledDowntime "downtime_' + self.__id + '" to ' + self.__type + '{\n'
        config += ValueMapper.parse_var('comment', self.__comment)
        config += ValueMapper.parse_var('author', self.__author)
        if None is not self.__duration and 'Service' == self.__type:
            # todo prüfen
            config += '  duration = "' + self.__duration + '"\n'
        if None is not self.__child_options:
            config += '  child_options = "' + self.__child_options + '"\n'

        config += ValueMapper.parse_var('fixed', self.__fixed)

        config += '  ranges = {\n'
        for range in self.__ranges:
            config += '    "' + range[0] + '" = "' + range[1] + '"\n'
        config += '  }\n'

        config += '  assign where "downtime_' + self.__id + '" in ' + self.__type.lower() + '.vars.' + self.__id + '\n'
        config += '}\n'

        return config



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.ValueChecker import ValueChecker


class PackageManager:

    def __init__(self, id):
        self.__id = id
        self.__manager = None

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)

        pm = None if force_create else ConfigBuilder.get_package_manager(id)
        if None is pm:
            pm = PackageManager(id)
            ConfigBuilder.add_package_manager(id, pm)

        return pm

    def get_id(self):
        return self.__id

    def set_manager(self, manager):
        ValueChecker.is_string(manager)
        self.__manager = manager
        return self

    def get_manager(self):
        return self.__manager

    def validate(self):
        if None is self.__manager:
            raise Exception('You have to specify Manager for ' + self.get_id())

    def get_config(self):
        self.validate()

        config = 'template Host "packagemanager_' + self.__id + '" {\n'
        config += '  vars.package_manager += ["' + self.__id + '"]\n'
        config += '}\n'

        return config


def apt(): return PackageManager.create('apt').set_manager('apt')


def yum(): return PackageManager.create('yum').set_manager('yum')


def apk(): return PackageManager.create('apk').set_manager('apk')


def rpm(): return PackageManager.create('rpm').set_manager('rpm')


def dpkg(): return PackageManager.create('dpkg').set_manager('dpkg')



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.Icinga2Confgen.SSHDSecurityCommand import SSHDSecurityCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckSSHDSecurity(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckSSHDSecurity', 'sshd_security')
        self.__permit_root_login = None
        self.__public_key_auth = None
        self.__password_auth = None
        self.__permit_empty_passwords = None
        self.__challenge_response_authentication = None
        self.__fingerprint_hash = None
        self.__port = None
        self.__config = []
        self.set_check_interval('6h')
        self.add_service_group(ServiceGroup.create('security'))
        self.add_service_group(ServiceGroup.create('sshd'))
        self.add_service_group(ServiceGroup.create('sshd_security'))

    def set_permit_root_login(self, permit_root_login):
        ValueChecker.is_string(permit_root_login)
        self.__permit_root_login = permit_root_login
        return self

    def get_permit_root_login(self):
        return self.__permit_root_login

    def set_public_key_auth(self, public_key_auth):
        ValueChecker.is_string(public_key_auth)
        self.__public_key_auth = public_key_auth
        return self

    def get_public_key_auth(self):
        return self.__public_key_auth

    def set_password_auth(self, password_auth):
        ValueChecker.is_string(password_auth)
        self.__password_auth = password_auth
        return self

    def get_password_auth(self):
        return self.__password_auth

    def set_permit_empty_passwords(self, permit_empty_passwords):
        ValueChecker.is_string(permit_empty_passwords)
        self.__permit_empty_passwords = permit_empty_passwords
        return self

    def get_permit_empty_passwords(self):
        return self.__permit_empty_passwords

    def set_fingerprint_hash(self, fingerprint_hash):
        ValueChecker.is_string(fingerprint_hash)
        self.__fingerprint_hash = fingerprint_hash
        return self

    def get_fingerprint_hash(self):
        return self.__fingerprint_hash

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_challenge_response_authentication(self, challenge_response_authentication):
        ValueChecker.is_string(challenge_response_authentication)
        self.__challenge_response_authentication = challenge_response_authentication
        return self

    def get_challenge_response_authentication(self):
        return self.__challenge_response_authentication

    def append_config_params(self, key, value):
        ValueChecker.is_string(key)
        ValueChecker.is_string(value)
        self.__config.append(key + "=" + value)
        return self

    def remove_config_params(self, key, value):
        ValueChecker.is_string(key)
        ValueChecker.is_string(value)
        self.__config.remove(key + "=" + value)
        return self

    def get_config_params(self):
        return self.__config

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckSSHDSecurity(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('sshd_security'):
            SSHDSecurityCommand.create('sshd_security')

        return check

    def validate(self):
        pass



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.


def get_default_group_name(id):
    default_names = {
        'amavisd': 'Amavisd',
        'antivirus': 'Antivirus',
        'apache': 'Apache',
        'apt': 'APT',
        'bind': 'Bind',
        'breeze': 'Breeze',
        'certificate_check': 'X.509 certificate',
        'clamd': 'Clamd',
        'containerd': 'Containerd',
        'cron': 'Cron',
        'database': 'Database',
        'deny_insecure_TLSv1_0_webserver': 'Deny insecure TLS 1.0 webserver',
        'deny_insecure_TLSv1_0_unchecked': 'Deny insecure TLS 1.0 unchecked',
        'deny_insecure_TLSv1_1_webserver': 'Deny insecure TLS 1.1 webserver',
        'deny_insecure_TLSv1_1_unchecked': 'Deny insecure TLS 1.1 unchecked',
        'deny_secure_TLSv1_2_webserver': 'Deny secure TLS 1.2 wevserver',
        'deny_secure_TLSv1_3_webserver': 'Deny secure TLS 1.3 wevserver',
        'dhcp': 'DHCP',
        'dig': 'dig',
        'disk': 'Disk',
        'dns': 'DNS',
        'dnssec': 'DNSSEC',
        'docker': 'Docker',
        'dovecot': 'Dovecot',
        'dummy': 'Dummy',
        'existing_user': 'Existing users',
        'file_age': 'File age',
        'firewall': 'Firewall',
        'flexlm': 'Flexlm',
        'freshclam': 'Freshclam',
        'ftp': 'FTP',
        'group_members': 'Group members',
        'hpjd': 'HP JD',
        'http_redirect': 'Http to https redirect',
        'http_redirect_unchecked': 'Http to https redirect unchecked',
        'icmp': 'ICMP',
        'ifstatus': 'Interface status',
        'imap': 'IMAP',
        'insecure_webserver': 'Insecure webserver',
        'insecure_TLSv1_0_Webserver': 'Insecure TLS v1.0 webserver',
        'insecure_TLSv1_1_Webserver': 'Insecure TLS v1.1 webserver',
        'ircd': 'IRCD',
        'jabber': 'Jabber',
        'ldap': 'LDAP',
        'load': 'Load',
        'log': 'Log',
        'mail': 'Mail',
        'mailq': 'Mail queue',
        'missing_http_redirect_check': 'Missing http to https redirect check',
        'mrt_gtraf': 'MRT graf',
        'mysql': 'MySQL',
        'network': 'Network',
        'nginx': 'NGINX',
        'nntp': 'NNTP',
        'no_certificate_check': 'No X.509 Certificate check',
        'ntp': 'NTP',
        'ns_client': 'NS Client',
        'opendkim': 'Open DKIM',
        'path_exists': 'Path exists',
        'php_fpm': 'PHP FPM',
        'postfix': 'Postfix',
        'postgres': 'PostgreSQL',
        'postgrey': 'Postgrey',
        'ping': 'Ping',
        'pop': 'POP',
        'procs': 'Procs',
        'radius': 'RADIUS',
        'rpc': 'RPC',
        'rsyslogd': 'Rsyslogd',
        'secure_webserver': 'Secure Webserver',
        'secure_TLSv1_2_unchecked': 'Secure TLS 1.2 unchecked',
        'secure_TLSv1_3_unchecked': 'Secure TLS 1.3 unchecked',
        'secure_TLSv1_2_webserver': 'Secure TLS 1.2 Webserver',
        'secure_TLSv1_3_webserver': 'Secure TLS 1.3 Webserver',
        'security': 'Security',
        'sensors': 'Sensors',
        'smart': 'SMART',
        'smtp': 'SMTP',
        'snmp': 'SNMP',
        'sshd': 'SSHD',
        'sshd_security': 'SSHD security',
        'sudoers': 'Sudoers',
        'swap': 'SWAP',
        'system_health': 'System health',
        'tcp': 'TCP',
        'tls': 'TLS',
        'tls_1_check': 'TLS v1.0 Check',
        'tls_1_1_check': 'TLS v1.1 Check',
        'tls_1_2_check': 'TLS v1.2 Check',
        'tls_1_3_check': 'TLS v1.3 Check',
        'tomcat': 'Apache Tomcat',
        'udp': 'UDP',
        'ufw': 'UFW',
        'ups': 'UPS',
        'updates': 'Updates',
        'uptime': 'Uptime',
        'user': 'User',
        'yum': 'YUM',
        'wave': 'Wave',
        'webserver': 'Webserver',
        'wordpress': 'Wordpress',
    }

    return default_names.get(id, id.replace('_', ' '))


def get_default_check_name(id, command_name):
    default_names = {
        'apt': 'APT',
        'breeze': 'Breeze',
        'clamd': 'Clamd',
        'deny_tls_version': 'Deny TLS version',
        'dhcp': 'DHCP',
        'dig': 'DIG',
        'disk': 'Disk',
        'disk_smb': 'Disk SMB',
        'dnssec_expiry': 'DNSSEC expire',
        'docker_login': 'Docker login',
        'domain_address_ipv4': 'DNS A',
        'domain_address_ipv6': 'DNS AAAA',
        'dummy': 'Dummy',
        'existing_users': 'Existing users',
        'file_age': 'File age',
        'flexlm': 'Flexlm',
        'ftp': 'FTP',
        'group_members': 'Group members',
        'hpjd': 'HP JD',
        'http': 'Http',
        'icmp': 'ICMP',
        'ide_smart': 'SMART',
        'ifstatus': 'Interface status',
        'imap': 'IMAP',
        'ircd': 'IRCD',
        'jabber': 'Jabber',
        'ldap': 'LDAP',
        'ldaps': 'LDAPS',
        'load': 'Load',
        'log': 'Log',
        'mailq': 'Mail queue',
        'mrt_gtraf': 'MRT gtraf',
        'mysql': 'MySQL',
        'mysql_query': 'MySQL query',
        'nntp': 'NNTP',
        'nntps': 'NNTPS',
        'nt': 'NT',
        'ntp_peer': 'NTP peer',
        'ntp_time': 'NTP time',
        'path_exist': 'Path exist',
        'pgsql': 'PostgreSQL',
        'ping': 'Ping',
        'ping4': 'Ping (ipv4)',
        'ping6': 'Ping (ipv6)',
        'pop': 'POP',
        'procs': 'Procs',
        'radius': 'RADIUS',
        'rpc': 'RPC',
        'running_proc_amavisd': 'Amavisd running',
        'running_proc_apache': 'Apache running',
        'running_proc_bind': 'Bind running',
        'running_proc_clamd': 'Clamd running',
        'running_proc_containerd': 'Containerd running',
        'running_proc_cron': 'Cron running',
        'running_proc_docker': 'Docker running',
        'running_proc_dovecot': 'Dovecot running',
        'running_proc_freshclam': 'Freshclam running',
        'running_proc_httpd': 'Httpd running',
        'running_proc_mysql': 'MySQL running',
        'running_proc_nginx': 'NGINX running',
        'running_proc_opendkim': 'Open DKIM running',
        'running_proc_php_fpm': 'PHP FPM running',
        'running_proc_postfix': 'Postfix running',
        'running_proc_postgres': 'PostgreSQL running',
        'running_proc_postgrey': 'Postgrey running',
        'running_proc_rsyslogd': 'Rsyslogd running',
        'running_proc_sshd': 'SSHD running',
        'running_proc_tomcat': 'Apache Tomcat running',
        'sensors': 'Sensors',
        'simap': 'IMAPS',
        'smtp': 'SMTP',
        'snmp': 'SNMP',
        'spop': 'POPS',
        'ssh': 'SSH',
        'sshd_security': 'SSHD security',
        'ssmtp': 'SMTPS',
        'sudoers_group_members': 'Sudoers group members',
        'swap': 'SWAP',
        'tcp': 'TCP',
        'udp': 'UDP',
        'ufw_status': 'UFW Status',
        'ups': 'UPS',
        'uptime': 'Uptime',
        'users': 'Users',
        'wave': 'Wave',
        'web_access_allow_tls1': 'Allow insecure TLS 1.0',
        'web_access_allow_tls1_1': 'Allow insecure TLS 1.1',
        'web_access_allow_tls1_2': 'Allow secure TLS 1.2',
        'web_access_allow_tls1_3': 'Allow secure TLS 1.3',
        'web_access_certificate': 'Certificate check',
        'web_access_default': 'Default web access',
        'web_access_deny_gitdir': 'Deny .git',
        'web_access_deny_gitignore': 'Deny .gitignore',
        'web_access_deny_license': 'Deny License',
        'web_access_deny_readme': 'Deny readme',
        'web_access_deny_tls1': 'Deny insecure TLS 1.0',
        'web_access_deny_tls1_1': 'Deny insecure TLS 1.1',
        'web_access_deny_tls1_2': 'Deny secure TLS 1.2',
        'web_access_deny_tls1_3': 'Deny secure TLS 1.3',
        'web_access_deny_wp_admin': 'deny /wp-admin',
        'web_access_deny_wp_includes': 'deny /wp-includes',
        'web_access_deny_wp_content': 'deny /wp-content',
        'web_access_deny_wp_login': 'deny /wp-login.php',
        'web_access_deny_wp_cron': 'deny /wp-cron.php',
        'web_access_deny_wp_load': 'deny /wp-load.php',
        'web_access_deny_wp_mail': 'deny /wp-mail.php',
        'web_access_deny_wp_signup': 'deny /wp-signup.php',
        'web_access_deny_wp_trackback': 'deny /wp-trackback.php',
        'web_access_deny_wp_xmlrpc': 'deny /xmlrpc.php',
        'web_access_deny_wp_config': 'deny /wp-config.php',
        'web_access_deny_wp_config_sample': 'deny /wp-config-sample.php',
        'web_access_deny_wp_blog_header': 'deny /wp-blog-header.php',
        'web_access_deny_wp_activate': 'deny /wp-activate.php',
        'web_access_deny_wp_links_opml': 'deny /wp-links-opml.php',
        'web_access_http_redirect': 'Http to https redirect',
        'web_access_missing_http_redirect': 'No http redirect check for',
        'wheel_group_members': 'Sudoers (wheel) group members',
        'yum': 'YUM',
    }

    for name in default_names:
        if id.startswith(name + '_'):
            return default_names[name]

    return default_names.get(id, default_names.get(command_name, command_name.replace('_', ' ')))



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.MonitoringPlugins.LDAPSCommand import LDAPSCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckLDAPS(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckLDAPS', 'ldaps')
        self.__host = None
        self.__port = None
        self.__use_ipv4 = False
        self.__use_ipv6 = False
        self.__attr = None
        self.__base = None
        self.__dn = None
        self.__pass = None
        self.__starttls = False
        self.__ssl = True
        self.__protocol_v2 = False
        self.__protocol_v3 = False
        self.__warning = None
        self.__critical = None
        self.__warning_entries = None
        self.__critical_entries = None
        self.__timeout = 10
        self.add_service_group(ServiceGroup.create('ldap'))

    def set_host(self, host):
        ValueChecker.is_string(host)
        self.__host = host
        return self

    def get_host(self):
        return self.__host

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_use_ipv4(self, use_ipv4):
        ValueChecker.is_bool(use_ipv4)
        self.__use_ipv4 = use_ipv4
        return self

    def get_use_ipv4(self):
        return self.__use_ipv4

    def set_use_ipv6(self, use_ipv6):
        ValueChecker.is_bool(use_ipv6)
        self.__use_ipv6 = use_ipv6
        return self

    def get_use_ipv6(self):
        return self.__use_ipv6

    def set_attr(self, attr):
        ValueChecker.is_string(attr)
        self.__attr = attr
        return self

    def get_attr(self):
        return self.__attr

    def set_base(self, base):
        ValueChecker.is_string(base)
        self.__base = base
        return self

    def get_base(self):
        return self.__base

    def set_dn(self, dn):
        ValueChecker.is_string(dn)
        self.__dn = dn
        return self

    def get_dn(self):
        return self.__dn

    def set_pass(self, passwd):
        ValueChecker.is_string(passwd)
        self.__pass = passwd
        return self

    def get_pass(self):
        return self.__pass

    def set_starttls(self, starttls):
        ValueChecker.is_bool(starttls)
        self.__starttls = starttls
        return self

    def get_starttls(self):
        return self.__starttls

    def set_ssl(self, ssl):
        ValueChecker.is_bool(ssl)
        self.__ssl = ssl
        return self

    def get_ssl(self):
        return self.__ssl

    def set_protocol_v2(self, protocol_v2):
        ValueChecker.is_bool(protocol_v2)
        self.__protocol_v2 = protocol_v2
        return self

    def get_protocol_v2(self):
        return self.__protocol_v2

    def set_protocol_v3(self, protocol_v3):
        ValueChecker.is_bool(protocol_v3)
        self.__protocol_v3 = protocol_v3
        return self

    def get_protocol_v3(self):
        return self.__protocol_v3

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        self.__warning = warning
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        self.__critical = critical
        return self

    def get_critical(self):
        return self.__critical

    def set_warning_entries(self, warning_entries):
        ValueChecker.is_number(warning_entries)
        self.__warning_entries = warning_entries
        return self

    def get_warning_entries(self):
        return self.__warning_entries

    def set_critical_entries(self, critical_entries):
        ValueChecker.is_number(critical_entries)
        self.__critical_entries = critical_entries
        return self

    def get_critical_entries(self):
        return self.__critical_entries

    def set_timeout(self, timeout):
        ValueChecker.is_number(timeout)
        self.__timeout = timeout
        return self

    def get_timeout(self):
        return self.__timeout

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            check = CheckLDAPS(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('ldaps'):
            LDAPSCommand.create('ldaps')

        return check

    def validate(self):
        if None is self.__base:
            raise Exception('You have to specify a base dn for ' + self.get_id())
        if None is self.__host:
            raise Exception('You have to specify a host for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.Checks.Check import Check
from icinga2confgen.Commands.Icinga2Confgen.PageContentCommand import PageContentCommand
from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.ValueChecker import ValueChecker


class CheckPageContent(Check):

    def __init__(self, id):
        Check.__init__(self, id, 'CheckPageContent', 'page_content')
        self.__ok = None
        self.__warning = None
        self.__critical = None
        self.__header = None
        self.__uri = None
        self.__domain = None
        self.__port = None
        self.__ssl = False
        self.__client_cert = None
        self.__client_key = None
        self.add_service_group(ServiceGroup.create('webserver'))

    def set_ok(self, ok):
        ValueChecker.is_string(ok)
        if None is self.__ok:
            self.__ok = []
        self.__ok.append(ok)
        return self

    def get_ok(self):
        return self.__ok

    def set_warning(self, warning):
        ValueChecker.is_string(warning)
        if None is self.__warning:
            self.__warning = []
        self.__warning.append(warning)
        return self

    def get_warning(self):
        return self.__warning

    def set_critical(self, critical):
        ValueChecker.is_string(critical)
        if None is self.__critical:
            self.__critical = []
        self.__critical.append(critical)
        return self

    def get_critical(self):
        return self.__critical

    def set_header(self, header):
        ValueChecker.is_string(header)
        if None is self.__header:
            self.__header = []
        self.__header.append(header)
        return self

    def get_header(self):
        return self.__header

    def set_uri(self, uri):
        ValueChecker.is_string(uri)
        self.__uri = uri
        return self

    def get_uri(self):
        return self.__uri

    def set_domain(self, domain):
        ValueChecker.is_string(domain)
        self.__domain = domain
        return self

    def get_domain(self):
        return self.__domain

    def set_port(self, port):
        ValueChecker.is_number(port)
        self.__port = port
        return self

    def get_port(self):
        return self.__port

    def set_ssl(self, ssl):
        ValueChecker.is_bool(ssl)
        self.__ssl = ssl
        return self

    def get_ssl(self):
        return self.__ssl

    def set_client_cert(self, client_cert):
        ValueChecker.is_string(client_cert)
        self.__client_cert = client_cert
        return self

    def get_client_cert(self):
        return self.__client_cert

    def set_client_key(self, client_key):
        ValueChecker.is_string(client_key)
        self.__client_key = client_key
        return self

    def get_client_key(self):
        return self.__client_key

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        check = None if force_create else ConfigBuilder.get_check(id)
        if None is check:
            id = 'check_' + id
            check = CheckPageContent(id)
            ConfigBuilder.add_check(id, check)

        if None is ConfigBuilder.get_command('page_content'):
            PageContentCommand.create('page_content')

        return check

    def validate(self):
        if None is self.__domain:
            raise Exception('You have to specify a domain for ' + self.get_id())



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.
from icinga2confgen.Checks.MonitoringPlugins.CheckHttp import CheckHttp
from icinga2confgen.Groups.HostGroup import HostGroup
from icinga2confgen.Groups.ServiceGroup import ServiceGroup
from icinga2confgen.Utils.DefaultGitChecks import DefaultGitChecks
from icinga2confgen.Utils.DefaultWebserverChecks import DefaultWebserverChecks
from icinga2confgen.ValueChecker import ValueChecker
from icinga2confgen.ValueMapper import ValueMapper


class DefaultWordpressChecks(DefaultWebserverChecks):

    def __init__(self, vhostconfig=[], servers=[], checkserver=[], notifications=[]):
        DefaultWebserverChecks.__init__(self, vhostconfig, servers, checkserver, notifications)
        self.__validate_deny_git = True
        self.__validate_deny_gitignore = True
        self.__validate_deny_license = True
        self.__validate_deny_readme = True
        self.__validate_deny_wp_admin = True
        self.__validate_deny_wp_includes = True
        self.__validate_deny_wp_content = True
        self.__validate_deny_wp_login = True
        self.__validate_deny_wp_cron = True
        self.__validate_deny_wp_load = True
        self.__validate_deny_wp_mail = True
        self.__validate_deny_wp_settings = True
        self.__validate_deny_wp_signup = True
        self.__validate_deny_wp_trackback = True
        self.__validate_deny_wp_xmlrpc = True
        self.__validate_deny_wp_config = True
        self.__validate_deny_wp_config_sample = True
        self.__validate_deny_wp_blog_header = True
        self.__validate_deny_wp_activate = True
        self.__validate_deny_wp_links_opml = True
        self.__inherit = True
        self.__git_checks = DefaultGitChecks(vhostconfig, servers, checkserver, notifications).set_inherit(False)

    def set_inherit(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__inherit = enabled

        return self

    def is_inherit(self):
        return self.__inherit

    def validate_deny_git(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_git = enabled

        return self

    def is_validating_deny_git(self):
        return self.__validate_deny_git

    def validate_deny_gitignore(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_gitignore = enabled

        return self

    def is_validating_deny_gitignore(self):
        return self.__validate_deny_gitignore

    def validate_deny_license(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_license = enabled

        return self

    def is_validating_deny_license(self):
        return self.__validate_deny_license

    def validate_deny_readme(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_readme = enabled

        return self

    def is_validating_deny_readme(self):
        return self.__validate_deny_readme

    def validate_deny_wp_admin(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_admin = enabled

        return self

    def is_validating_deny_wp_admin(self):
        return self.__validate_deny_wp_admin

    def validate_deny_wp_includes(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_includes = enabled

        return self

    def is_validating_deny_wp_includes(self):
        return self.__validate_deny_wp_includes

    def validate_deny_wp_content(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_content = enabled

        return self

    def is_validating_deny_wp_content(self):
        return self.__validate_deny_wp_content

    def validate_deny_wp_login(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_login = enabled

        return self

    def is_validating_deny_wp_login(self):
        return self.__validate_deny_wp_login

    def validate_deny_wp_cron(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_cron = enabled

        return self

    def is_validating_deny_wp_cron(self):
        return self.__validate_deny_wp_cron

    def validate_deny_wp_load(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_load = enabled

        return self

    def is_validating_deny_wp_load(self):
        return self.__validate_deny_wp_load

    def validate_deny_wp_mail(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_mail = enabled

        return self

    def is_validating_deny_wp_mail(self):
        return self.__validate_deny_wp_mail

    def validate_deny_wp_settings(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_settings = enabled

        return self

    def is_validating_deny_wp_settings(self):
        return self.__validate_deny_wp_settings

    def validate_deny_wp_signup(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_signup = enabled

        return self

    def is_validating_deny_wp_signup(self):
        return self.__validate_deny_wp_signup

    def validate_deny_wp_trackback(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_trackback = enabled

        return self

    def is_validating_deny_wp_trackback(self):
        return self.__validate_deny_wp_trackback

    def validate_deny_wp_xmlrpc(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_xmlrpc = enabled

        return self

    def is_validating_deny_wp_xmlrpc(self):
        return self.__validate_deny_wp_xmlrpc

    def validate_deny_wp_config(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_config = enabled

        return self

    def is_validating_deny_wp_config(self):
        return self.__validate_deny_wp_config

    def validate_deny_wp_config_sample(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_config_sample = enabled

        return self

    def is_validating_deny_wp_config_sample(self):
        return self.__validate_deny_wp_config_sample

    def validate_deny_wp_blog_header(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_blog_header = enabled

        return self

    def is_validating_deny_wp_blog_header(self):
        return self.__validate_deny_wp_blog_header

    def validate_deny_wp_activate(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_activate = enabled

        return self

    def is_validating_deny_wp_activate(self):
        return self.__validate_deny_wp_activate

    def validate_deny_wp_links_opml(self, enabled):
        ValueChecker.is_bool(enabled)
        self.__validate_deny_wp_links_opml = enabled

        return self

    def is_validating_deny_wp_links_opml(self):
        return self.__validate_deny_wp_links_opml

    def create_wp_check(self, name, base_id, server, domain, uri):

        if None is server.get_ipv4() and None is server.get_ipv6():
            raise Exception('It is required to set the ipv4 or ipv6 on the server with id "' +
                            server.get_id() + '", before you can apply this checks!')

        if None is not server.get_ipv4():
            check = CheckHttp.create('web_access_deny_' + name + '_ipv4_' + base_id)
            check.set_ip(server.get_ipv4()) \
                .set_vhost(domain) \
                .set_uri(uri) \
                .set_ssl(True) \
                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                .set_expect('40') \
                .set_check_interval('1d') \
                .set_display_name(check.get_display_name() + ' ' + domain) \
                .add_service_group(ServiceGroup.create('wordpress')) \
                .add_service_group(ServiceGroup.create('webserver'))
            self.apply_notification_to_check(check)

            for checkserver in DefaultWebserverChecks.get_checkservers(self):
                checkserver.add_check(check)

        if None is not server.get_ipv6():
            check = CheckHttp.create('web_access_deny_' + name + '_ipv6_' + base_id)
            check.set_ip(server.get_ipv6()) \
                .set_vhost(domain) \
                .set_uri(uri) \
                .set_ssl(True) \
                .set_sni(DefaultWebserverChecks.get_sni(self)) \
                .set_expect('40') \
                .set_check_interval('1d') \
                .set_display_name(check.get_display_name() + ' ' + domain) \
                .add_service_group(ServiceGroup.create('wordpress')) \
                .add_service_group(ServiceGroup.create('webserver'))
            self.apply_notification_to_check(check)

            for checkserver in DefaultWebserverChecks.get_checkservers(self):
                checkserver.add_check(check)

    def apply(self):
        if self.__inherit:
            DefaultWebserverChecks.apply(self)

        self.__git_checks.validate_deny_git(self.__validate_deny_git) \
            .validate_deny_gitignore(self.__validate_deny_gitignore) \
            .apply()

        for config in DefaultWordpressChecks.get_vhostconfigs(self):
            service_baseid = config[0]
            domain = config[1]

            for server in DefaultWebserverChecks.get_servers(self):
                server.add_hostgroup(HostGroup.create('wordpress'))
                base_id = service_baseid + '_' + server.get_id() + '_' + ValueMapper.canonicalize_for_id(domain)

                if True is self.__validate_deny_license:
                    self.create_wp_check('license', base_id, server, domain, '/license.txt')
                if True is self.__validate_deny_readme:
                    self.create_wp_check('readme', base_id, server, domain, '/readme.html')
                if True is self.__validate_deny_wp_admin:
                    self.create_wp_check('wp_admin', base_id, server, domain, '/wp-admin/')
                if True is self.__validate_deny_wp_content:
                    self.create_wp_check('wp_includes', base_id, server, domain, '/wp-includes/')
                if True is self.__validate_deny_wp_content:
                    self.create_wp_check('wp_content', base_id, server, domain, '/wp-content/')
                if True is self.__validate_deny_wp_login:
                    self.create_wp_check('wp_login', base_id, server, domain, '/wp-login.php')
                if True is self.__validate_deny_wp_cron:
                    self.create_wp_check('wp_cron', base_id, server, domain, '/wp-cron.php')
                if True is self.__validate_deny_wp_load:
                    self.create_wp_check('wp_load', base_id, server, domain, '/wp-load.php')
                if True is self.__validate_deny_wp_mail:
                    self.create_wp_check('wp_mail', base_id, server, domain, '/wp-mail.php')
                if True is self.__validate_deny_wp_signup:
                    self.create_wp_check('wp_signup', base_id, server, domain, '/wp-signup.php')
                if True is self.__validate_deny_wp_trackback:
                    self.create_wp_check('wp_trackback', base_id, server, domain, '/wp-trackback.php')
                if True is self.__validate_deny_wp_xmlrpc:
                    self.create_wp_check('wp_xmlrpc', base_id, server, domain, '/xmlrpc.php')
                if True is self.__validate_deny_wp_config:
                    self.create_wp_check('wp_config', base_id, server, domain, '/wp-config.php')
                if True is self.__validate_deny_wp_config_sample:
                    self.create_wp_check('wp_config_sample', base_id, server, domain, '/wp-config-sample.php')
                if True is self.__validate_deny_wp_blog_header:
                    self.create_wp_check('wp_blog_header', base_id, server, domain, '/wp-blog-header.php')
                if True is self.__validate_deny_wp_activate:
                    self.create_wp_check('wp_activate', base_id, server, domain, '/wp-activate.php')
                if True is self.__validate_deny_wp_links_opml:
                    self.create_wp_check('wp_links_opml', base_id, server, domain, '/wp-links-opml.php')



#!/usr/bin/python3
# -*- coding: utf-8

#  Icinga2 configuration generator
#
#  Icinga2 configuration file generator for hosts, commands, checks, ... in python
#
#  Copyright (c) 2020 Fabian Fröhlich <mail@icinga2.confgen.org> https://icinga2.confgen.org
#
#
#  This program is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Affero General Public License as
#  published by the Free Software Foundation, either version 3 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Affero General Public License for more details.
#
#  You should have received a copy of the GNU Affero General Public License
#  along with this program.  If not, see <https://www.gnu.org/licenses/>.
#
#  For all license terms see README.md and LICENSE Files in root directory of this Project.

from icinga2confgen.ConfigBuilder import ConfigBuilder
from icinga2confgen.Groups.Group import Group
from icinga2confgen.ValueChecker import ValueChecker


class ServiceGroup(Group):

    def __init__(self, id):
        Group.__init__(self, id, 'service')

    @staticmethod
    def create(id, force_create=False):
        ValueChecker.validate_id(id)
        servicegroup = None if force_create else ConfigBuilder.get_servicegroup(id)
        if None is servicegroup:
            servicegroup = ServiceGroup(id)
            ConfigBuilder.add_servicegroup(id, servicegroup)

        return servicegroup
